#!/bin/sh
echo 'name: postgresql-libpq
version: 0.9.0.1
id: postgresql-libpq-0.9.0.1-090b3eef19460778fbfb5ff7cba74ba1

license: BSD3
copyright: (c) 2010 Grant Monroe
           (c) 2011 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
stability:
homepage: http://github.com/lpsmith/postgresql-libpq
package-url:
synopsis: low-level binding to libpq
description: This is a binding to libpq: the C application
             programmer'\''s interface to PostgreSQL. libpq is a
             set of library functions that allow client
             programs to pass queries to the PostgreSQL
             backend server and to receive the results of
             these queries.
category: Database
author: Grant Monroe, Leon P Smith, Joey Adams
pkgpath: databases/hs-postgresql-libpq
exposed: True
exposed-modules: Database.PostgreSQL.LibPQ
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/postgresql-libpq-0.9.0.1
library-dirs: /usr/local/lib/ghc/postgresql-libpq-0.9.0.1
              /usr/local/lib
hs-libraries: HSpostgresql-libpq-0.9.0.1
extra-libraries: crypto ssl pq
extra-ghci-libraries:
include-dirs: /usr/local/include/postgresql
includes:
depends: base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-postgresql-libpq-0.9.0.1/html/postgresql-libpq.haddock
haddock-html: /usr/local/share/doc/hs-postgresql-libpq-0.9.0.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
